@@ -21,16 +21,8 @@
 
 #include "iapws.h"
 
-typedef enum {
-	ICE_IH  = 1,
-	ICE_III = 3,
-	ICE_V   = 5,
-	ICE_VI  = 6,
-	ICE_VII = 7,
-} ice_phase_id;
-
-double melt_p(double t, ice_phase_id phase);
+double melt_p(double t, enum iapws_ice phase);
 double sub_p(double t);
-iapws_state_id melt_sub_state(double p, double t);
+enum iapws_state melt_sub_state(double p, double t);
 
 #endif
